summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRay Lai <ray@cvs.openbsd.org>2007-08-26 07:38:39 +0000
committerRay Lai <ray@cvs.openbsd.org>2007-08-26 07:38:39 +0000
commit03e2dc743caa490af3863d6a863288cfd7a23e31 (patch)
tree1b6bb2db48ca8b5a1ace999a38315b66dbe07403
parent6bb4b324034c3e3b5cecd1118d160617d498de6e (diff)
Fix some error messages and comments, from Brad.
OK otto.
-rw-r--r--libexec/identd/identd.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/libexec/identd/identd.c b/libexec/identd/identd.c
index fa6e4886680..0e72e69b69b 100644
--- a/libexec/identd/identd.c
+++ b/libexec/identd/identd.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: identd.c,v 1.43 2007/06/28 21:43:36 millert Exp $ */
+/* $OpenBSD: identd.c,v 1.44 2007/08/26 07:38:38 ray Exp $ */
/*
* This program is in the public domain and may be used freely by anyone
@@ -318,13 +318,13 @@ main(int argc, char *argv[])
}
if (set_gid) {
if (setegid(set_gid) == -1)
- error("main: setgid");
+ error("main: setegid");
if (setgid(set_gid) == -1)
error("main: setgid");
}
if (set_uid) {
if (seteuid(set_uid) == -1)
- error("main: setuid");
+ error("main: seteuid");
if (setuid(set_uid) == -1)
error("main: setuid");
}
@@ -371,10 +371,10 @@ main(int argc, char *argv[])
} while (nfds < 0 && errno == EINTR);
/*
* An error occurred in select? Just die
*/
if (nfds < 0)
- error("main: select");
+ error("main: poll");
/*
* Timeout limit reached. Exit nicely
@@ -423,7 +423,7 @@ main(int argc, char *argv[])
* reach to other end anyway, so lets give the poor user some
* errors.
*/
- perror("in.identd: getpeername()");
+ perror("identd: getpeername()");
exit(1);
}
if (sa.ss_family == AF_INET6) {
@@ -371,10 +371,10 @@ main(int argc, char *argv[])
} while (nfds < 0 && errno == EINTR);
/*
- * An error occurred in select? Just die
+ * An error occurred in poll? Just die
*/
if (nfds < 0)